<?php

namespace Drp\SimpleCms;

use Drp\SimpleCms\Contracts\Publishable;
use Illuminate\Contracts\Validation\Factory;
use Illuminate\Validation\ValidationException;

class Validator
{
    /**
     * @var Factory
     */
    private $validator;

    public function __construct(Factory $validator)
    {
        $this->validator = $validator;
    }

    public function validateContent(Publishable $content): bool
    {
        //Map each attribute using the models getters
        //this takes advantage of the casting so we
        //get any arrays that are stored as json
        // phpcs:disable Generic.CodeAnalysis.UnusedFunctionParameter.Found
        $attributes = collect($content)
            ->map(function ($attribute, $key) use ($content) {
                return $content->$key;
            })->toArray();
        // phpcs:enable Generic.CodeAnalysis.UnusedFunctionParameter.Found

        $validator = $this->validator->make($attributes, $content->getPublishRules(), $content->getPublishMessages());

        if ($validator->fails()) {
            flash()->error(trans('validation.error'));
            throw new ValidationException(
                $validator,
                redirect()
                    ->back()
                    ->withInput($attributes)
                    ->withErrors($validator->errors()->getMessages())
            );
        }

        return true;
    }
}
